"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthorizedGenericClient = exports.GenericClient = exports.classJSONRPCServerException = exports.JSONRPCException = void 0;
const DEFAULT_TIMEOUT = 10000;
class JSONRPCException extends Error {
    constructor({ code, message, data }) {
        super(message);
        this.code = code;
        this.data = data;
    }
}
exports.JSONRPCException = JSONRPCException;
class classJSONRPCServerException extends Error {
}
exports.classJSONRPCServerException = classJSONRPCServerException;
class GenericClient {
    constructor({ url, token, module, timeout }) {
        this.url = url;
        this.token = token || null;
        this.module = module;
        this.timeout = timeout || DEFAULT_TIMEOUT;
    }
    makePayload(method, param) {
        return {
            jsonrpc: '2.0',
            method: this.module + '.' + method,
            id: String(Math.random()).slice(2),
            params: param
        };
    }
    processResponse(response) {
        const responseText = response.data;
        if (responseText.length === 0) {
            throw new Error('Empty response');
        }
        let responseData;
        try {
            responseData = JSON.parse(responseText);
        }
        catch (ex) {
            console.error('error', ex);
            throw new Error('Error parsing response as JSON: ' + ex.message);
        }
        if ('error' in responseData) {
            console.warn('about to throw error', responseData.error);
            throw new JSONRPCException(responseData.error);
        }
        return responseData.result;
    }
    callFunc(func, param) {
        return __awaiter(this, void 0, void 0, function* () {
            const headers = {
                'Content-Type': 'application/json',
                'Accept': 'application/json'
            };
            if (this.token) {
                headers['Authorization'] = this.token;
            }
            const params = this.makePayload(func, param);
            const response = yield axios.post(this.url, params, {
                headers,
                timeout: this.timeout,
                responseType: 'text'
            });
            return this.processResponse(response);
        });
    }
}
exports.GenericClient = GenericClient;
class AuthorizedGenericClient extends GenericClient {
    constructor(params) {
        super(params);
        if (!params.token) {
            throw new Error('Authorized client requires token');
        }
        this.token = params.token;
    }
    callFunc(func, param) {
        return __awaiter(this, void 0, void 0, function* () {
            const headers = {
                'Content-Type': 'application/json',
                'Accept': 'application/json',
                'Authorization': this.token
            };
            if (this.token) {
                headers['Authorization'] = this.token;
            }
            const params = this.makePayload(func, param);
            const response = yield axios.post(this.url, params, {
                headers,
                timeout: this.timeout,
                responseType: 'text',
                transformResponse: (data) => {
                    return data;
                }
            });
            return this.processResponse(response);
        });
    }
}
exports.AuthorizedGenericClient = AuthorizedGenericClient;
//# sourceMappingURL=GenericClientx.js.map