export interface CacheParams {
    itemLifetime: number;
    monitoringFrequency: number;
    waiterTimeout: number;
    waiterFrequency: number;
}
export interface CacheItem<T> {
    id: string;
    value: T | null;
    createdAt: number;
    fetcher: () => Promise<T>;
    reserved: boolean;
}
export declare type Fetcher<T> = () => Promise<T>;
export declare class Cache<T> {
    cache: Map<string, CacheItem<T>>;
    cacheLifetime: number;
    monitoringFrequency: number;
    waiterTimeout: number;
    waiterFrequency: number;
    isMonitoring: boolean;
    constructor({ itemLifetime, monitoringFrequency, waiterTimeout, waiterFrequency }: CacheParams);
    private runMonitor;
    private isExpired;
    private getItem;
    private reserveWaiter;
    private reserveAndFetch;
    getItemWithWait({ id, fetcher }: {
        id: string;
        fetcher: Fetcher<T>;
    }): Promise<any>;
    private reserveItem;
    private setItem;
}
export interface DynamicServiceClientParams {
    token: string;
    url: string;
    version?: string;
    timeout?: number;
    rpcContext?: any;
}
export interface ServiceCallResult<T> {
    version: '1.1';
    id: string;
    result: T;
}
export declare class DynamicServiceClient {
    token: string;
    timeout: number;
    rpcContext: any;
    url: string;
    version: string | null;
    static module: string;
    constructor({ token, url, version, timeout, rpcContext }: DynamicServiceClientParams);
    private options;
    private getModule;
    private moduleId;
    private getCached;
    private lookupModule;
    protected callFunc<P, T>(funcName: string, params: P): Promise<T>;
}
