"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthorizedServiceClient = exports.ServiceClient = void 0;
const axios_1 = __importDefault(require("axios"));
class ServiceClient {
    constructor({ url, token, timeout }) {
        this.url = url;
        this.token = token || null;
        this.timeout = timeout;
    }
    makePayload(method, param) {
        return {
            version: '1.1',
            method: this.constructor.module + '.' + method,
            id: String(Math.random()).slice(2),
            params: [param]
        };
    }
    makeEmptyPayload(method) {
        return {
            version: '1.1',
            method: this.constructor.module + '.' + method,
            id: String(Math.random()).slice(2),
            params: []
        };
    }
}
exports.ServiceClient = ServiceClient;
class AuthorizedServiceClient extends ServiceClient {
    constructor(params) {
        super(params);
        if (!params.token) {
            throw new Error('Authorized client requires token');
        }
        this.token = params.token;
    }
    callFunc(func, param) {
        return new Promise((resolve, reject) => {
            const connection = axios_1.default.post(this.url, this.makePayload(func, param), {
                headers: {
                    Authorization: this.token,
                    'Content-Type': 'application/json',
                    Accept: 'application/json'
                },
                timeout: this.timeout
            });
            connection.then((response) => {
                resolve(response.data);
            })
                .catch((err) => {
                reject(err);
            });
        });
    }
}
exports.AuthorizedServiceClient = AuthorizedServiceClient;
//# sourceMappingURL=ServiceClient.js.map