"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DynamicServiceClient = void 0;
const ServiceWizard_1 = require("../coreServices/ServiceWizard");
const GenericClient_1 = require("./GenericClient");
const Cache_1 = __importDefault(require("../Cache"));
var moduleCache = new Cache_1.default({
    itemLifetime: 1800000,
    monitoringFrequency: 60000,
    waiterTimeout: 30000,
    waiterFrequency: 100
});
const DEFAULT_TIMEOUT = 10000;
class DynamicServiceClient {
    constructor({ token, url, version, timeout, rpcContext, urlBaseOverride }) {
        this.token = token;
        this.timeout = timeout || DEFAULT_TIMEOUT;
        this.rpcContext = rpcContext || null;
        this.urlBaseOverride = urlBaseOverride || null;
        if (!url) {
            throw new Error('The service discovery url was not provided');
        }
        this.url = url;
        this.version = version || null;
        if (version === 'auto') {
            this.version = null;
        }
    }
    options() {
        return {
            timeout: this.timeout,
            authorization: this.token,
            rpcContext: this.rpcContext
        };
    }
    getModule() {
        return this.constructor.module;
    }
    moduleId() {
        let moduleId;
        if (!this.version) {
            moduleId = this.getModule() + ':auto';
        }
        else {
            moduleId = this.getModule() + ':' + this.version;
        }
        return moduleId;
    }
    getCached(fetcher) {
        return moduleCache.getItemWithWait({
            id: this.moduleId(),
            fetcher: fetcher
        });
    }
    lookupModule() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.getCached(() => {
                const client = new ServiceWizard_1.ServiceWizardClient({
                    url: this.url,
                    token: this.token,
                    timeout: this.timeout
                });
                return Promise.resolve(client.get_service_status({
                    module_name: this.getModule(),
                    version: this.version
                }));
            });
        });
    }
    callFunc(funcName, params) {
        return __awaiter(this, void 0, void 0, function* () {
            const { url, module_name } = yield this.lookupModule();
            const client = new GenericClient_1.AuthorizedGenericClient({
                module: module_name,
                url,
                token: this.token,
                timeout: this.timeout
            });
            return yield client.callFunc(funcName, params);
        });
    }
}
exports.DynamicServiceClient = DynamicServiceClient;
//# sourceMappingURL=DynamicServiceClient.js.map