import { AxiosResponse } from 'axios';
export interface GenericClientParams {
    url: string;
    module: string;
    token?: string;
    timeout?: number;
}
export interface JSONRPCPayload<T> {
    jsonrpc: string;
    method: string;
    id: string;
    params: T;
}
export interface JSONRPCError<T> {
    code: number;
    message: string;
    data: T;
}
export declare class JSONRPCException<T> extends Error {
    code: number;
    data: T;
    constructor({ code, message, data }: JSONRPCError<T>);
}
export declare class classJSONRPCServerException extends Error {
}
export interface JSONRPCResultBase {
    jsonrpc: '2.0';
    id: string;
}
export interface JSONRPCSuccessResult<T> extends JSONRPCResultBase {
    result: T;
}
export interface JSONRPCErrorResult<T> extends JSONRPCResultBase {
    error: JSONRPCError<T>;
}
export declare type JSONRPCResult<T, E> = JSONRPCSuccessResult<T> | JSONRPCErrorResult<E>;
export declare class GenericClient {
    url: string;
    token: string | null;
    module: string;
    timeout?: number;
    constructor({ url, token, module, timeout }: GenericClientParams);
    protected makePayload<T>(method: string, param: T): JSONRPCPayload<T>;
    protected processResponse<T, E>(response: AxiosResponse<string>): T;
    callFunc<P, R, E>(func: string, param: P): Promise<R>;
}
export interface AuthorizedGenericClientParams extends GenericClientParams {
    token: string;
}
export declare class AuthorizedGenericClient extends GenericClient {
    token: string;
    constructor(params: AuthorizedGenericClientParams);
    callFunc<P, R, E>(func: string, param: P): Promise<R>;
}
